==> aliyun-python-sdk-mse-3.0.22.tar.gz: aliyun-python-sdk-mse-3.0.22/aliyunsdkmse/request/v20190531/AddGatewaySlbRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data

class AddGatewaySlbRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddGatewaySlb','mse')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SlbId(self): # String
		return self.get_query_params().get('SlbId')

	def set_SlbId(self, SlbId):  # String
		self.add_query_param('SlbId', SlbId)
	def get_GatewayUniqueId(self): # String
		return self.get_query_params().get('GatewayUniqueId')

	def set_GatewayUniqueId(self, GatewayUniqueId):  # String
		self.add_query_param('GatewayUniqueId', GatewayUniqueId)
	def get_Type(self): # String
		return self.get_query_params().get('Type')

	def set_Type(self, Type):  # String
		self.add_query_param('Type', Type)
	def get_HttpPort(self): # Integer
		return self.get_query_params().get('HttpPort')

	def set_HttpPort(self, HttpPort):  # Integer
		self.add_query_param('HttpPort', HttpPort)
	def get_ServiceWeight(self): # Integer
		return self.get_query_params().get('ServiceWeight')

	def set_ServiceWeight(self, ServiceWeight):  # Integer
		self.add_query_param('ServiceWeight', ServiceWeight)
	def get_VServerGroupId(self): # String
		return self.get_query_params().get('VServerGroupId')

	def set_VServerGroupId(self, VServerGroupId):  # String
		self.add_query_param('VServerGroupId', VServerGroupId)
	def get_HttpsVServerGroupId(self): # String
		return self.get_query_params().get('HttpsVServerGroupId')

	def set_HttpsVServerGroupId(self, HttpsVServerGroupId):  # String
		self.add_query_param('HttpsVServerGroupId', HttpsVServerGroupId)
	def get_AcceptLanguage(self): # String
		return self.get_query_params().get('AcceptLanguage')

	def set_AcceptLanguage(self, AcceptLanguage):  # String
		self.add_query_param('AcceptLanguage', AcceptLanguage)
	def get_HttpsPort(self): # Integer
		return self.get_query_params().get('HttpsPort')

	def set_HttpsPort(self, HttpsPort):  # Integer
		self.add_query_param('HttpsPort', HttpsPort)

==> aliyun-python-sdk-mse-3.0.24.tar.gz: aliyun-python-sdk-mse-3.0.24/aliyunsdkmse/request/v20190531/AddGatewaySlbRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkmse.endpoint import endpoint_data
import json

class AddGatewaySlbRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'mse', '2019-05-31', 'AddGatewaySlb','mse')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_SlbId(self): # String
		return self.get_query_params().get('SlbId')

	def set_SlbId(self, SlbId):  # String
		self.add_query_param('SlbId', SlbId)
	def get_GatewayUniqueId(self): # String
		return self.get_query_params().get('GatewayUniqueId')

	def set_GatewayUniqueId(self, GatewayUniqueId):  # String
		self.add_query_param('GatewayUniqueId', GatewayUniqueId)
	def get_Type(self): # String
		return self.get_query_params().get('Type')

	def set_Type(self, Type):  # String
		self.add_query_param('Type', Type)
	def get_HttpPort(self): # Integer
		return self.get_query_params().get('HttpPort')

	def set_HttpPort(self, HttpPort):  # Integer
		self.add_query_param('HttpPort', HttpPort)
	def get_ServiceWeight(self): # Integer
		return self.get_query_params().get('ServiceWeight')

	def set_ServiceWeight(self, ServiceWeight):  # Integer
		self.add_query_param('ServiceWeight', ServiceWeight)
	def get_VServerGroupId(self): # String
		return self.get_query_params().get('VServerGroupId')

	def set_VServerGroupId(self, VServerGroupId):  # String
		self.add_query_param('VServerGroupId', VServerGroupId)
	def get_VServiceList(self): # Array
		return self.get_query_params().get('VServiceList')

	def set_VServiceList(self, VServiceList):  # Array
		self.add_query_param("VServiceList", json.dumps(VServiceList))
	def get_HttpsVServerGroupId(self): # String
		return self.get_query_params().get('HttpsVServerGroupId')

	def set_HttpsVServerGroupId(self, HttpsVServerGroupId):  # String
		self.add_query_param('HttpsVServerGroupId', HttpsVServerGroupId)
	def get_AcceptLanguage(self): # String
		return self.get_query_params().get('AcceptLanguage')

	def set_AcceptLanguage(self, AcceptLanguage):  # String
		self.add_query_param('AcceptLanguage', AcceptLanguage)
	def get_HttpsPort(self): # Integer
		return self.get_query_params().get('HttpsPort')

	def set_HttpsPort(self, HttpsPort):  # Integer
		self.add_query_param('HttpsPort', HttpsPort)
